@@ -82,6 +82,7 @@ enum State {
     PARSE_MOVIE_EXPECT_DIV3,
     PARSE_MOVIE_DIV3,
     PARSE_MOVIE_TIME,
+    PARSE_NEXT_PAGE_LINK
 };
 
 void TheaterScheduleSearchClient::ReplyFinished(QNetworkReply *reply)
@@ -92,11 +93,13 @@ void TheaterScheduleSearchClient::ReplyFinished(QNetworkReply *reply)
     QVector<QString> movie_spans;
     QString theaters_url;
     double rating = -1.0;
-    QList<QTime> schedule;
+    QList<QString> schedule;
     QRegExp time_pattern("\\d+:\\d+([aApP][mM])*");
     QRegExp duration_pattern("((\\d+)hr )?(\\d+)min");
     QRegExp reviews_pattern("\\d+ review(s)?");
     QXmlStreamReader xml(reply);
+    QString next_page_url;
+    int next_page_start;
     while (!xml.atEnd()) {
         QXmlStreamReader::TokenType token = xml.readNext();
         if (token == QXmlStreamReader::StartElement) {
@@ -122,6 +125,16 @@ void TheaterScheduleSearchClient::ReplyFinished(QNetworkReply *reply)
                     rating = -1.0;
                     schedule.clear();
                     state = PARSE_MOVIE_LINK;
+                } else if (url.hasQueryItem("start")) {
+                    QString sort = url.queryItemValue("sort");
+                    QString start = url.queryItemValue("start");
+                    int istart = start.toInt();
+                    if (sort == "0" && istart > GetStartIndex()) {
+                        std::cout << "next page LINK " << qPrintable(attr_href) << std::endl;
+                        next_page_url = attr_href;
+                        next_page_start = istart;
+                    }
+                    state = PARSE_NEXT_PAGE_LINK;
                 } else {
                     state = PARSE_HTML;
                 }
@@ -202,13 +215,21 @@ void TheaterScheduleSearchClient::ReplyFinished(QNetworkReply *reply)
                                     movie->SetComment(s);
                                 }
                             }
-                            Q_FOREACH(const QTime time, schedule) {
-                                _cinema_schedule->AddSchedule(cinema, movie, time, _date);
+                            QList<QTime> schedule_times = TimesFromString(schedule);
+                            Q_FOREACH(const QTime time, schedule_times) {
+                                if (time.hour() < 3) {
+                                    // interpret very early times as shifted by 1 day (seems to be a Google logic)
+                                    _cinema_schedule->AddSchedule(cinema, movie, time, _date.addDays(1));
+                                } else {
+                                    _cinema_schedule->AddSchedule(cinema, movie, time, _date);
+                                }
                             }
                         }
                     }
                 }
                 state = PARSE_HTML;
+            } else if (state == PARSE_NEXT_PAGE_LINK) {
+                state = PARSE_HTML;
             }
         } else if (token == QXmlStreamReader::Characters) {
             if (state == PARSE_MOVIE_LINK) {
@@ -228,11 +249,8 @@ void TheaterScheduleSearchClient::ReplyFinished(QNetworkReply *reply)
                 int i = 0;
                 while ((i = time_pattern.indexIn(t, i)) != -1) {
                     int length = time_pattern.matchedLength();
-                    QTime time = TimeUtils::FromTimeString(t.mid(i, length));
-                    if (time.isValid()) {
-                        schedule.append(time);
-                    } else {
-                        //std::cout << "ERROR: time " << qPrintable(t.mid(i, length)) << " is invalid." << std::endl;
+                    if (length > 0) {
+                        schedule.append(t.mid(i, length));
                     }
                     i += length;
                 }
@@ -248,15 +266,18 @@ void TheaterScheduleSearchClient::ReplyFinished(QNetworkReply *reply)
         emit Cancelled(GetSearchTaskId());
         emit SearchFinished(GetSearchTaskId(), false);
     } else {
-        // all movies are listed on one page
-        // no repetition of search with start parameter
-        if (!_date_urls.isEmpty()) {
+        if (!next_page_url.isEmpty()) {
             emit Reply(GetSearchTaskId(), true);
-            SearchNextDate();
+            SearchEncodedUrl(next_page_url, next_page_start);
         } else {
-            emit Reply(GetSearchTaskId(), false);
-            emit SearchFinished(GetSearchTaskId(), true);
-            deleteLater();
+            if (!_date_urls.isEmpty()) {
+                emit Reply(GetSearchTaskId(), true);
+                SearchNextDate();
+            } else {
+                emit Reply(GetSearchTaskId(), false);
+                emit SearchFinished(GetSearchTaskId(), true);
+                deleteLater();
+            }
         }
     }
     reply->deleteLater();
