@@ -47,6 +47,7 @@ void TheaterSearchClient::CancelAllRunningSearchs()
 void TheaterSearchClient::Search(int start)
 {
     QUrl url("http://www.google.com/m/movies");
+    url.addQueryItem("action","chgloc");
     url.addQueryItem("loc", _town);
     url.addQueryItem("sort", QString::number(0));
     AbstractSearchClient::Search(url, start);
@@ -58,11 +59,13 @@ enum State {
     PARSE_THEATER_DIV,
     PARSE_THEATER_BR,
     PARSE_THEATER_SPAN,
-    PARSE_THEATER_PHONE
+    PARSE_THEATER_PHONE,
+    PARSE_NEXT_PAGE_LINK
 };
 
 void TheaterSearchClient::ReplyFinished(QNetworkReply *reply)
 {
+    //std::cout << qPrintable(QString::fromUtf8(reply->readAll().data())) << std::endl;
     QXmlStreamReader xml(reply);
     State state = PARSE_HTML;
     int found = 0;
@@ -70,6 +73,8 @@ void TheaterSearchClient::ReplyFinished(QNetworkReply *reply)
     QString theater_address;
     QString theater_movies_url;
     QString theater_phone;
+    QString next_page_url;
+    int next_page_start;
     while (!xml.atEnd()) {
         QXmlStreamReader::TokenType token = xml.readNext();
         if (token == QXmlStreamReader::StartElement) {
@@ -84,6 +89,16 @@ void TheaterSearchClient::ReplyFinished(QNetworkReply *reply)
                     theater_movies_url = attr_href;
                     theater_phone = "";
                     state = PARSE_THEATER_LINK;
+                } else if (url.hasQueryItem("start")) {
+                    QString sort = url.queryItemValue("sort");
+                    QString start = url.queryItemValue("start");
+                    int istart = start.toInt();
+                    if (sort == "0" && istart > GetStartIndex()) {
+                        std::cout << "next page LINK " << qPrintable(attr_href) << std::endl;
+                        next_page_url = attr_href;
+                        next_page_start = istart;
+                    }
+                    state = PARSE_NEXT_PAGE_LINK;
                 } else {
                     state = PARSE_HTML;
                 }
@@ -127,6 +142,8 @@ void TheaterSearchClient::ReplyFinished(QNetworkReply *reply)
                     }
                 }
                 state = PARSE_HTML;
+            } else if (state == PARSE_NEXT_PAGE_LINK) {
+                state = PARSE_HTML;
             }
         } else if (token == QXmlStreamReader::Characters) {
             if (state == PARSE_THEATER_LINK) {
@@ -148,9 +165,9 @@ void TheaterSearchClient::ReplyFinished(QNetworkReply *reply)
         emit SearchFinished(GetSearchTaskId(), false);
         deleteLater();
     } else {
-        if (found > 0) {
+        if (!next_page_url.isEmpty()) {
             emit Reply(GetSearchTaskId(), true);
-            Search(GetStartIndex() + found);
+            SearchEncodedUrl(next_page_url, next_page_start);
         } else {
             emit Reply(GetSearchTaskId(), false);
             emit SearchFinished(GetSearchTaskId(), true);
