@@ -31,6 +31,9 @@ public:
 
     static void ShowError(const QString &errormsg);
 
+    static bool IsLandscape();
+
+    static bool IsPortrait();
 };
 
 #endif // UIUTILS_H
